@@ -1,7 +1,7 @@
 package GIS::Distance::Fast;
 use 5.008001;
 use strictures 2;
-our $VERSION = '0.12';
+our $VERSION = '0.13';
 
 our @ISA;
 
@@ -28,29 +28,44 @@ GIS::Distance::Fast - C implementation of GIS::Distance formulas.
 
 This distribution re-implements some, but not all, of the formulas
 that come with L<GIS::Distance> in the C programming language.  C code
-is generally much faster than the perl equivilent.
+is generally much faster than the Perl equivalent.
 
-In most of my testing I've found that the C version of the formulas
-outperform the Perl equivelent by at least 2x.
+See L<GIS::Distance/SPEED> for some benchmarking and how to run your
+own benchmarks.
 
 This module need not be used directly.  L<GIS::Distance> will automatically
-use the ::Fast formulas when they are available.
+use the C<GIS::Distance::Fast::*> formulas when installed.
 
 =head1 FORMULAS
 
+=over
+
+=item *
+
 L<GIS::Distance::Fast::Cosine>
 
+=item *
+
 L<GIS::Distance::Fast::GreatCircle>
 
+=item *
+
 L<GIS::Distance::Fast::Haversine>
 
+=item *
+
 L<GIS::Distance::Fast::Polar>
 
+=item *
+
 L<GIS::Distance::Fast::Vincenty>
 
+=back
+
 =head1 SUPPORT
 
-Please submit bugs and feature requests to the GIS-Distance-Fast GitHub issue tracker:
+Please submit bugs and feature requests to the
+GIS-Distance-Fast GitHub issue tracker:
 
 L<https://github.com/bluefeet/GIS-Distance-Fast/issues>
 
