@@ -1,15 +1,14 @@
 package GIS::Distance::Fast::ALT;
 use 5.008001;
 use strictures 2;
-our $VERSION = '0.12';
+our $VERSION = '0.13';
+
+use parent 'GIS::Distance::Formula';
 
 use GIS::Distance::Fast;
 use namespace::clean;
 
-{
-    no strict 'refs';
-    *distance = \&GIS::Distance::Fast::alt_distance;
-}
+*_distance = \&GIS::Distance::Fast::alt_distance;
 
 1;
 __END__
@@ -24,14 +23,23 @@ GIS::Distance::Fast::ALT - C implementation of GIS::Distance::ALT.
 
 See L<GIS::Distance::ALT> for details about this formula.
 
+The code for this formula was taken from L<GIS::Distance::XS> and
+modified to fit.
+
 Normally this module is not used directly.  Instead L<GIS::Distance>
 is used which in turn interfaces with the various formula modules.
 
-=head1 AUTHORS AND LICENSE
+=head1 SUPPORT
 
-This formula was taken from L<GIS::Distance::XS> and modified to fit.
+See L<GIS::Distance::Fast/SUPPORT>.
 
-See L<GIS::Distance::Fast/AUTHORS> and L<GIS::Distance::Fast/LICENSE>.
+=head1 AUTHORS
+
+See L<GIS::Distance::Fast/AUTHORS>.
+
+=head1 LICENSE
+
+See L<GIS::Distance::Fast/LICENSE>.
 
 =cut
 
