@@ -1,15 +1,14 @@
 package GIS::Distance::Fast::Haversine;
 use 5.008001;
 use strictures 2;
-our $VERSION = '0.12';
+our $VERSION = '0.13';
+
+use parent 'GIS::Distance::Formula';
 
 use GIS::Distance::Fast;
 use namespace::clean;
 
-{
-    no strict 'refs';
-    *distance = \&GIS::Distance::Fast::haversine_distance;
-}
+*_distance = \&GIS::Distance::Fast::haversine_distance;
 
 1;
 __END__
@@ -27,11 +26,17 @@ See L<GIS::Distance::Haversine> for details about this formula.
 Normally this module is not used directly.  Instead L<GIS::Distance>
 is used which in turn interfaces with the various formula modules.
 
-=cut
+=head1 SUPPORT
 
-=head1 AUTHORS AND LICENSE
+See L<GIS::Distance::Fast/SUPPORT>.
 
-See L<GIS::Distance::Fast/AUTHORS> and L<GIS::Distance::Fast/LICENSE>.
+=head1 AUTHORS
+
+See L<GIS::Distance::Fast/AUTHORS>.
+
+=head1 LICENSE
+
+See L<GIS::Distance::Fast/LICENSE>.
 
 =cut
 
