@@ -1,15 +1,14 @@
 package GIS::Distance::Fast::Vincenty;
 use 5.008001;
 use strictures 2;
-our $VERSION = '0.12';
+our $VERSION = '0.13';
+
+use parent 'GIS::Distance::Formula';
 
 use GIS::Distance::Fast;
 use namespace::clean;
 
-{
-    no strict 'refs';
-    *distance = \&GIS::Distance::Fast::vincenty_distance;
-}
+*_distance = \&GIS::Distance::Fast::vincenty_distance;
 
 1;
 __END__
@@ -31,9 +30,17 @@ the Perl code.
 Normally this module is not used directly.  Instead L<GIS::Distance>
 is used which in turn interfaces with the various formula modules.
 
-=head1 AUTHORS AND LICENSE
+=head1 SUPPORT
 
-See L<GIS::Distance::Fast/AUTHORS> and L<GIS::Distance::Fast/LICENSE>.
+See L<GIS::Distance::Fast/SUPPORT>.
+
+=head1 AUTHORS
+
+See L<GIS::Distance::Fast/AUTHORS>.
+
+=head1 LICENSE
+
+See L<GIS::Distance::Fast/LICENSE>.
 
 =cut
 
